@@ -41,24 +41,25 @@ class GridHandler():
     def run_parser(self):
         parser = self.get_parser()
         if os.path.basename(sys.argv[0]) == 'hpogrid':
-            args = parser.parse_args(sys.argv[2:])
+            args, extra = parser.parse_known_args(sys.argv[2:])
         else:
-            args = parser.parse_args(sys.argv[1:])
+            args, extra = parser.parse_known_args(sys.argv[1:])
         self.submit(args.input, 
                     n_jobs=args.n_jobs,
                     site=args.site,
                     time=args.time,
                     search_points = args.search_points,
-                    mode=args.mode)
+                    mode=args.mode,
+                    extra=extra)
     
     @staticmethod
-    def submit(config_input:str, n_jobs=1, site=None, time=-1, search_points=None, mode='grid'):
+    def submit(config_input:str, n_jobs=1, site=None, time=-1, search_points=None, mode='grid', extra=[]):
         config = GridHandler.preprocess_config(config_input)
         if mode == 'grid':
             GridHandler.submit_grid(config, n_jobs=n_jobs, site=site,
-                                    time=time, search_points=search_points)
+                                    time=time, search_points=search_points, extra=extra)
         elif mode == 'idds':
-            GridHandler.submit_idds(config, n_jobs=n_jobs, site=site)
+            GridHandler.submit_idds(config, n_jobs=n_jobs, site=site, extra=extra)
         else:
             raise ValueError('Unknown job submission mode: {}'.format(mode))
             
@@ -76,7 +77,7 @@ class GridHandler():
         return config
         
     @staticmethod
-    def submit_idds(config, n_jobs=1, site=None):
+    def submit_idds(config, n_jobs=1, site=None, extra=[]):
         project_path = helper.get_project_path(config['project_name'])
         print('INFO: Submitting {} idds grid job(s)'.format(n_jobs))
         with tempfile.TemporaryDirectory() as tmpdirname:
@@ -90,25 +91,27 @@ class GridHandler():
                 json.dump(search_space, search_space_file)  
             command = GridHandler.format_idds_command(config, 
                                                tmpdirname,
-                                               site=site)
+                                               site=site,
+                                               extra=extra)
             with helper.cd(project_path):
                 # submit jobs
                 for _ in range(n_jobs):
                     os.system(command)
     @staticmethod
-    def submit_grid(config, n_jobs=1, site=None, time=-1, search_points=None):
+    def submit_grid(config, n_jobs=1, site=None, time=-1, search_points=None, extra=[]):
         project_path = helper.get_project_path(config['project_name'])
         print('INFO: Submitting {} grid job(s)'.format(n_jobs))
         command = GridHandler.format_grid_command(config, site=site,
                                                   time=time,
-                                                  search_points=search_points)
+                                                  search_points=search_points,
+                                                  extra=extra)
         with helper.cd(project_path):
             # submit jobs
             for _ in range(n_jobs):
                 os.system(command)
                 
     @staticmethod
-    def format_idds_command(config, tmpdirname, site=None):
+    def format_idds_command(config, tmpdirname, site=None, extra=[]):
         idds_config_path = os.path.join(tmpdirname, 'idds_config.json')
         search_space_path = os.path.join(tmpdirname, 'search_space.json')
         options = {'loadJson': idds_config_path,
@@ -136,11 +139,11 @@ class GridHandler():
             out_ds = out_ds.format(HPO_PROJECT_NAME=proj_name)
         options['outDS'] = out_ds
                 
-        command = 'phpo {}'.format(stylus.join_options(options))    
+        command = 'phpo {} {}'.format(stylus.join_options(options), ' '.join(extra))    
         return command
     
     @staticmethod
-    def format_grid_command(config, site=None, time=-1, search_points=None):
+    def format_grid_command(config, site=None, time=-1, search_points=None, extra=[]):
         options = {'forceStaged': '',
                    'useSandbox': '',
                    'noBuild': '',
@@ -179,8 +182,8 @@ class GridHandler():
             # specify architecture for gpu/cpu site
             if 'GPU' in site:
                 options['cmtConfig'] = 'nvidia-gpu'
-        
-        command = 'prun {}'.format(stylus.join_options(options))
                 
+        
+        command = 'prun {} {}'.format(stylus.join_options(options), ' '.join(extra))
         return command        
                 
\ No newline at end of file
