@@ -40,6 +40,60 @@ class ConfigurationBase():
             description=self.description,
             usage=self.usage) 
         return parser
+    
+    @staticmethod
+    def get_parser_test(config_type, parent_parser=None, **kwargs):
+        parser = argparse.ArgumentParser(**kwargs) 
+        subparsers = parser.add_subparsers(help='actions')
+        def get_usage_str(action):
+            return 'hpogrid {} {} [<options>]'.format(config_type, action)
+        # action = list
+        parser_list = subparsers.add_parser('list', 
+        description='List all configuration files',
+        usage=get_usage_str('list'),
+        prog=get_usage_str('list'))
+        parser_list.add_argument('-e', '--expression', metavar='',
+                help='Filter out configuration files that matches the expression',
+                required=False)
+        
+        # action = show
+        parser_show = subparsers.add_parser('show', 
+        description='Display the content of a configuration file',
+        usage=get_usage_str('show'),
+        prog=get_usage_str('show'))
+        parser_show.add_argument('name', help='Name of the configuration file to show')
+        
+        # action = remove
+        parser_remove = subparsers.add_parser('remove', 
+        description='Remove a configuration file',
+        usage=get_usage_str('remove'),
+        prog=get_usage_str('remove'))
+        parser_remove.add_argument('name', help='Name of the configuration file to remove')
+        
+        if parent_parser is None:
+            parent_parser = argparse.ArgumentParser(add_help=False)
+        
+        # action = create
+        parser_create = subparsers.add_parser('create', 
+        description='Create a new configuration file',
+        usage=get_usage_str('create'),
+        prog=get_usage_str('create'),
+        parents=[parent_parser])
+        
+        # action = update
+        parser_update = subparsers.add_parser('update', 
+        description='Update a configuration file',
+        usage=get_usage_str('update'),
+        prog=get_usage_str('update'),
+        parents=[parent_parser])
+        
+        # action = recreate
+        parser_recreate = subparsers.add_parser('recreate', 
+        description='Recreate a configuration file',
+        usage=get_usage_str('recreate'),
+        prog=get_usage_str('recreate'),
+        parents=[parent_parser])        
+        return parser
 
     def get_parser(self, action=None):
         parser = self.get_base_parser()           
