@@ -15,6 +15,23 @@ class SearchSpaceConfiguration(ConfigurationBase):
     list_columns = ['Search Space Configuration']
     show_columns = ['Hyperparameters', 'Search Space']  
     json_interpreted = []
+    
+    @staticmethod
+    def get_parser_test():
+        parser, subparsers = ConfigurationBase.get_parser_test(
+            description='Manage configuration for hyperparameter search space',
+            usage='hpogrid search_space <action> <config_name> <search_space_definition>')
+        for action in subparsers.choices:
+            subparsers.choices[action].usage = subparsers.choices[action].usage.replace('<config_type>', 'search_space')
+        for action in ['create', 'update', 'recreate']:
+            parser_action = subparsers.choices.get(action, None)
+            if parser_action is None:
+                raise RuntimeError('Subparser {} not found'.format(action))
+            parser_action.add_argument('name', metavar='',
+                help='Name given to the search space file')  
+            parser_action.add_argument('search_space',metavar='', 
+                help='A json decodable string defining the search space')  
+        return parser
 
     def get_parser(self, action=None):
         parser = self.get_base_parser()               
