@@ -63,6 +63,9 @@ class SteeringIDDS():
         elif lib == 'bohb':
             from hpogrid.generator.bohb_generator import BOHBGenerator
             return BOHBGenerator(space, metric, mode, **args) 
+        elif lib == 'grid':
+            from hpogrid.generator.grid_generator import GridBGenerator
+            return GridBGenerator(space, metric, mode, **args)         
         else:
             raise ValueError('Generator from library {} is not supported'.format(lib))
 
